"use strict";
/*
 * Copyright 2018 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.V1ApiClient = void 0;
const ask_sdk_1 = require("ask-sdk");
class V1ApiClient {
    constructor() {
        this.defaultApiClient = new ask_sdk_1.DefaultApiClient();
    }
    post(uri, headers, body) {
        const options = this.buildOptions(uri, headers, 'POST');
        return this.dispatch(options, body);
    }
    put(uri, headers, body) {
        const options = this.buildOptions(uri, headers, 'PUT');
        return this.dispatch(options, body);
    }
    get(uri, headers) {
        const options = this.buildOptions(uri, headers, 'GET');
        return this.dispatch(options);
    }
    delete(uri, headers) {
        const options = this.buildOptions(uri, headers, 'DELETE');
        return this.dispatch(options);
    }
    buildOptions(uri, requestHeaders, requestMethod) {
        const request = {
            headers: requestHeaders,
            method: requestMethod,
            url: uri,
        };
        return request;
    }
    dispatch(options, body) {
        options.body = body;
        return this.defaultApiClient.invoke(options);
    }
}
exports.V1ApiClient = V1ApiClient;
//# sourceMappingURL=v1ApiClient.js.map